@@ -1,38 +1,26 @@
 /*
- * Copyright (c) 2000 Silicon Graphics, Inc.  All Rights Reserved.
- * 
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of version 2 of the GNU General Public License as
+ * Copyright (c) 2000-2002 Silicon Graphics, Inc.
+ * All Rights Reserved.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation.
- * 
- * This program is distributed in the hope that it would be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * 
- * Further, this software is distributed without any warranty that it is
- * free of the rightful claim of any third person regarding infringement
- * or the like.  Any license provided herein, whether implied or
- * otherwise, applies only to this software file.  Patent licenses, if
- * any, provided herein do not apply to combinations of this program with
- * other software, or any other product whatsoever.
- * 
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write the Free Software Foundation, Inc., 59
- * Temple Place - Suite 330, Boston MA 02111-1307, USA.
- * 
- * Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
- * Mountain View, CA  94043, or:
- * 
- * http://www.sgi.com 
- * 
- * For further information regarding this notice, see: 
- * 
- * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
+ *
+ * This program is distributed in the hope that it would be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write the Free Software Foundation,
+ * Inc.,  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include <libxfs.h>
-#include <jdm.h>
+#include <xfs/xfs.h>
+#include <xfs/jdm.h>
 
+#include <unistd.h>
+#include <stdlib.h>
 #include <fcntl.h>
 #include <time.h>
 #include <stdlib.h>
@@ -40,6 +28,11 @@
 #include <unistd.h>
 #include <stdio.h>
 #include <sys/stat.h>
+#include <assert.h>
+#include <string.h>
+#include <uuid/uuid.h>
+
+#include "config.h"
 
 #include "types.h"
 #include "mlog.h"
@@ -59,10 +52,10 @@ inv_open( inv_predicate_t bywhat, inv_oflag_t forwhat, void *pred )
 	int fd, stobjfd, num, retval;
 	inv_idbtoken_t tok = INV_TOKEN_NULL;
 	invt_sescounter_t *sescnt = 0;
-	
+
 	int index = 0;
 	
-	ASSERT ( pred );
+	assert ( pred );
 	fd = retval = init_idb ( pred, bywhat, forwhat, &tok );
 
 	if ( retval == I_DONE ) 
@@ -86,7 +79,7 @@ inv_open( inv_predicate_t bywhat, inv_oflag_t forwhat, void *pred )
 		return INV_TOKEN_NULL;
 	}
 
-	ASSERT ( index > 0 );
+	assert ( index > 0 );
 
 	/* Now we need to make sure that this has enough space */
 	INVLOCK( stobjfd, LOCK_SH );
@@ -102,7 +95,7 @@ inv_open( inv_predicate_t bywhat, inv_oflag_t forwhat, void *pred )
 	/* create another storage object ( and, an inv_index entry for it 
 	   too ) if we've filled this one up */
 
-	if ( (u_int) num >= sescnt->ic_maxnum ) {
+	if ( (uint) num >= sescnt->ic_maxnum ) {
 		mlog( MLOG_DEBUG | MLOG_INV, "$ INV: creating a new storage obj & "
 		      "index entry. \n" );
 		INVLOCK( stobjfd, LOCK_UN );
@@ -171,29 +164,30 @@ inv_writesession_open(
 	bool_t		ispartial,
 	bool_t		isresumed,
 	u_char		level,
-	u_int		nstreams,
+	uint		nstreams,
 	time32_t	time,
 	char		*mntpt,
 	char		*devpath )
 {
 	invt_session_t  ses;
 	int		fd;
-	intgen_t	rval;
+	int	rval;
 	invt_sescounter_t *sescnt = NULL;
 	invt_seshdr_t  	hdr;
 	inv_sestoken_t	sestok;
 	inv_oflag_t     forwhat;
 
-	ASSERT ( tok != INV_TOKEN_NULL );
-	ASSERT ( sesid && fsid && mntpt && devpath );
+	assert ( tok != INV_TOKEN_NULL );
+	assert ( sesid && fsid && mntpt && devpath );
 	forwhat = tok->d_oflag;
 	fd = tok->d_stobj_fd;
-	ASSERT ( forwhat != INV_SEARCH_ONLY );
-	ASSERT ( fd > 0 );
+	assert ( forwhat != INV_SEARCH_ONLY );
+	assert ( fd > 0 );
 
 	if ( ! ( tok->d_update_flag & FSTAB_UPDATED ) ) {
 		if ( fstab_put_entry( fsid, mntpt, devpath, forwhat ) < 0 ) {
-		       mlog( MLOG_NORMAL | MLOG_INV, "INV: put_fstab_entry failed.\n");
+		       mlog( MLOG_NORMAL | MLOG_INV, _(
+				"INV: put_fstab_entry failed.\n") );
 		       return INV_TOKEN_NULL;
 		}
 		tok->d_update_flag |= FSTAB_UPDATED;
@@ -231,7 +225,7 @@ inv_writesession_open(
 	/* create the writesession, and get ready for the streams to come 
 	   afterwards */
 	rval = stobj_create_session( sestok, fd, sescnt, &ses, &hdr );
-	ASSERT (rval > 0);
+	assert (rval > 0);
 
 
 	INVLOCK( fd, LOCK_UN );
@@ -240,7 +234,8 @@ inv_writesession_open(
 
 	if ( tok->d_update_flag & NEW_INVINDEX ) {
 		if ( idx_put_sesstime( sestok, INVT_STARTTIME ) < 0 ) {
-			mlog( MLOG_NORMAL | MLOG_INV, "INV: put_starttime failed.\n");
+			mlog( MLOG_NORMAL | MLOG_INV, _(
+				"INV: put_starttime failed.\n") );
 			return INV_TOKEN_NULL;
 		}
 		tok->d_update_flag &= ~(NEW_INVINDEX);
@@ -268,7 +263,7 @@ inv_writesession_close( inv_sestoken_t tok )
 {
 	int		rval;
 	
-	ASSERT ( tok != INV_TOKEN_NULL );
+	assert ( tok != INV_TOKEN_NULL );
 
 	/* now update end_time in the inv index header */
 	rval = idx_put_sesstime( tok, INVT_ENDTIME );
@@ -299,7 +294,7 @@ inv_stream_open(
 	int fd;
 	bool_t err = BOOL_FALSE;
 
-	ASSERT ( tok != INV_TOKEN_NULL );
+	assert ( tok != INV_TOKEN_NULL );
 	 
 	/* this memset is needed as a dump interrupted/crashed very soon
 	 * after starting results in an inventory with exteremely large
@@ -339,8 +334,9 @@ inv_stream_open(
 				     tok->sd_session_off ) < 0 ) 
 			err = BOOL_TRUE;
 	} else if ( ! err ) {
-		mlog ( MLOG_NORMAL, "INV: cant create more than %d streams."
-		       " Max'd out..\n", ses.s_cur_nstreams );
+		mlog ( MLOG_NORMAL, _(
+		       "INV: cant create more than %d streams."
+		       " Max'd out..\n"), ses.s_cur_nstreams );
 		err = BOOL_TRUE;
 	}
 
@@ -385,8 +381,9 @@ inv_stream_close(
 	
 	rval = idx_put_sesstime( tok->md_sesstok, INVT_ENDTIME );
 	if (rval < 0)
-		mlog( MLOG_NORMAL | MLOG_INV, "INV: idx_put_sesstime failed in "
-		      "inv_stream_close() \n");
+		mlog( MLOG_NORMAL | MLOG_INV, _(
+		      "INV: idx_put_sesstime failed in "
+		      "inv_stream_close() \n") );
 	INVLOCK( fd, LOCK_EX );
 	if ((rval = GET_REC_NOLOCK( fd, &strm, sizeof( invt_stream_t ), 
 			       tok->md_stream_off )) > 0 ) {
@@ -443,7 +440,7 @@ inv_put_mediafile(
 	inv_stmtoken_t 	tok, 
 	uuid_t 		*moid, 
 	char 		*label,
-	u_int		mfileindex,
+	uint		mfileindex,
 	xfs_ino_t	startino,
 	off64_t		startino_offset,
 	xfs_ino_t	endino,
@@ -456,9 +453,9 @@ inv_put_mediafile(
 	int 		 rval;
 
 
-	ASSERT ( tok != INV_TOKEN_NULL );
-	ASSERT ( tok->md_sesstok->sd_invtok->d_update_flag & FSTAB_UPDATED );
-	ASSERT ( tok->md_sesstok->sd_invtok->d_stobj_fd >= 0 );
+	assert ( tok != INV_TOKEN_NULL );
+	assert ( tok->md_sesstok->sd_invtok->d_update_flag & FSTAB_UPDATED );
+	assert ( tok->md_sesstok->sd_invtok->d_stobj_fd >= 0 );
 
 	mf = (invt_mediafile_t *) calloc( 1, sizeof( invt_mediafile_t ) );
 	
@@ -522,8 +519,8 @@ inv_get_sessioninfo(
 	int		fd;
 
 
-	ASSERT( tok != INV_TOKEN_NULL );
-	ASSERT( tok->sd_invtok );
+	assert( tok != INV_TOKEN_NULL );
+	assert( tok->sd_invtok );
 	*bufpp = NULL;
 	*bufszp = 0;
 	fd = tok->sd_invtok->d_stobj_fd;
@@ -589,8 +586,8 @@ inv_free_session(
 {
 	uint i;
 	
-	ASSERT(ses);
-	ASSERT(*ses);
+	assert(ses);
+	assert(*ses);
 
 	for ( i = 0; i < (*ses)->s_nstreams; i++ ) {
 		/* the array of mediafiles is contiguous */
@@ -606,69 +603,78 @@ inv_free_session(
 
 
 /*----------------------------------------------------------------------*/
-/* inventory_lasttime_level_lessthan					*/
-/*                                                                      */
-/* Given a token that refers to a file system, and a level, this returns*/
-/* the last time when a session of a lesser level was done.             */
-/*                                                                      */
-/* returns -1 on error.                                                 */
+/* inv_lasttime_level_lessthan						*/
+/*									*/
+/* Given a file system uuid, token that refers to a file system, and a	*/
+/* level, tm is populated with last time when a session of a lesser	*/
+/* level was done.							*/
+/*									*/
+/* Returns TRUE on success.						*/
 /*----------------------------------------------------------------------*/
 
 bool_t
 inv_lasttime_level_lessthan( 
-	inv_idbtoken_t  tok,
-	u_char level,
-	time32_t **tm )
+	uuid_t		*fsidp,
+	inv_idbtoken_t	tok,
+	u_char		level,
+	time32_t	**tm)
 {
 	int 	rval;
 	if ( tok != INV_TOKEN_NULL ) {
-		rval =  search_invt( tok->d_invindex_fd, &level, (void **) tm,
-				    (search_callback_t) tm_level_lessthan );
+		rval =  search_invt(fsidp, tok->d_invindex_fd, &level,
+				    (void **)tm,
+				    (search_callback_t)tm_level_lessthan);
 
 		return ( rval < 0) ? BOOL_FALSE: BOOL_TRUE;
 	}
 	
-	return invmgr_query_all_sessions((void *) &level, /* in */
-					 (void **) tm,   /* out */
-			       (search_callback_t) tm_level_lessthan); 
+	return invmgr_query_all_sessions(fsidp,		 /* fs uuid ptr */
+					 (void *)&level, /* in */
+					 (void **)tm,	 /* out */
+			       (search_callback_t)tm_level_lessthan);
 }
 
-
-
-
-
 /*----------------------------------------------------------------------*/
-/*                                                                      */
-/*                                                                      */
-/*                                                                      */
+/* inv_lastsession_level_lessthan					*/
+/*									*/
+/* Given a file system uuid, token that refers to a file system, and a	*/
+/* level, ses is populated with a session of lesser than the level	*/
+/* passed in.								*/
+/*									*/
+/* Returns FALSE on an error, TRUE if not. If (*ses) is NULL, then the	*/
+/* search failed.                                                       */
 /*----------------------------------------------------------------------*/
 
 bool_t
 inv_lastsession_level_lessthan( 
-	inv_idbtoken_t 	tok,
+	uuid_t		*fsidp,
+	inv_idbtoken_t	tok,
 	u_char		level,
-	inv_session_t 	**ses )
+	inv_session_t	**ses)
 {
 	int 	rval;
 	if ( tok != INV_TOKEN_NULL ) {
-		rval = search_invt( tok->d_invindex_fd, &level, (void **) ses, 
-				   (search_callback_t) lastsess_level_lessthan );
+		rval = search_invt(fsidp, tok->d_invindex_fd, &level,
+				   (void **)ses,
+				   (search_callback_t)lastsess_level_lessthan);
 
 		return ( rval < 0) ? BOOL_FALSE: BOOL_TRUE;
 	}
 
-	return invmgr_query_all_sessions((void *) &level, /* in */
-					 (void **) ses,   /* out */
-			       (search_callback_t) lastsess_level_lessthan);
+	return invmgr_query_all_sessions(fsidp,		 /* fs uuid */
+					 (void *)&level, /* in */
+					 (void **)ses,	 /* out */
+			       (search_callback_t)lastsess_level_lessthan);
 
 }
 
-
-
-
 /*----------------------------------------------------------------------*/
-/*                                                                      */
-/*                                                                      */
+/* inv_lastsession_level_equalto					*/
+/*									*/
+/* Given a file system uuid, token that refers to a file system, and a	*/
+/* level, this populates ses with last time when a session of a lesser	*/
+/* level was done.							*/
+/*									*/
 /* Return FALSE on an error, TRUE if not. If (*ses) is NULL, then the   */
 /* search failed.                                                       */
 /*----------------------------------------------------------------------*/
@@ -676,21 +682,24 @@ inv_lastsession_level_lessthan(
 
 bool_t
 inv_lastsession_level_equalto( 
-	inv_idbtoken_t 	tok,			    
+	uuid_t		*fsidp,
+	inv_idbtoken_t	tok,
 	u_char		level,
 	inv_session_t	**ses )
 {
 	int 	rval;
 	if ( tok != INV_TOKEN_NULL ) {
-		rval = search_invt( tok->d_invindex_fd, &level, (void **) ses, 
-				   (search_callback_t) lastsess_level_equalto );
+		rval = search_invt(fsidp, tok->d_invindex_fd, &level,
+				   (void **)ses,
+				   (search_callback_t)lastsess_level_equalto);
 
 		return ( rval < 0) ? BOOL_FALSE: BOOL_TRUE;
 	}
 	
-	return invmgr_query_all_sessions((void *) &level, /* in */
-					 (void **) ses,   /* out */
-			       (search_callback_t) lastsess_level_equalto);
+	return invmgr_query_all_sessions(fsidp,		 /* fs uuid */
+					 (void *)&level, /* in */
+					 (void **)ses,	 /* out */
+			       (search_callback_t)lastsess_level_equalto);
 
 }
 
@@ -698,35 +707,45 @@ inv_lastsession_level_equalto(
 /*----------------------------------------------------------------------*/
 /* inv_getsession_byuuid                                                */
 /*                                                                      */
+/* Given a file system uuid and a session uuid , ses is populated with	*/
+/* the session that contains the matching system uuid.			*/
+/*									*/
+/* Returns FALSE on an error, TRUE if the session was found.		*/
 /*----------------------------------------------------------------------*/
 
 bool_t
 inv_get_session_byuuid(
-	uuid_t	*sesid,
-	inv_session_t **ses)
+	uuid_t		*fsidp,
+	uuid_t		*sesid,
+	inv_session_t	**ses)
 {
 
-	return (invmgr_query_all_sessions((void *)sesid, /* in */
-					  (void **) ses, /* out */
-			       (search_callback_t) stobj_getsession_byuuid));
+	return invmgr_query_all_sessions(fsidp,		/* fs uuid */
+					 (void *)sesid, /* in */
+					 (void **)ses,	/* out */
+			       (search_callback_t)stobj_getsession_byuuid);
 }
 
-
-
 /*----------------------------------------------------------------------*/
-/* inv_getsession_byuuid                                                */
+/* inv_getsession_bylabel						*/
 /*                                                                      */
+/* Given a file system uuid and a session uuid, ses is populated with	*/
+/* the session that contains the matching system label.			*/
+/*									*/
+/* Returns FALSE on an error, TRUE if the session was found.		*/
 /*----------------------------------------------------------------------*/
 
 bool_t
 inv_get_session_bylabel(
-	char *session_label,
-	inv_session_t **ses)
+	uuid_t		*fsidp,
+	char		*session_label,
+	inv_session_t	**ses)
 {
 
-	return (invmgr_query_all_sessions((void *)session_label, /* in */
-					  (void **) ses, /* out */
-			       (search_callback_t) stobj_getsession_bylabel));
+	return invmgr_query_all_sessions(fsidp,			/* fs uuid */
+					 (void *)session_label, /* in */
+					 (void **)ses,		/* out */
+			       (search_callback_t)stobj_getsession_bylabel);
 }
 
 
@@ -770,7 +789,7 @@ inv_delete_mediaobj( uuid_t *moid )
 
 	fd = fstab_getall( &arr, &cnt, &numfs, forwhat );
 	if ( fd < 0 || numfs <= 0 ) {
-		mlog( MLOG_NORMAL | MLOG_INV, "INV: Error in fstab\n" );
+		mlog( MLOG_NORMAL | MLOG_INV, _("INV: Error in fstab\n") );
 		return BOOL_FALSE;
 	}
 	
@@ -783,23 +802,21 @@ inv_delete_mediaobj( uuid_t *moid )
 				      forwhat
 				     )
 		     < 0 ) {
-			mlog( MLOG_NORMAL | MLOG_INV,
-			     "INV: Cant get inv-name for uuid\n"
-			     );
+			mlog( MLOG_NORMAL | MLOG_INV, _(
+			      "INV: Cant get inv-name for uuid\n") );
 			return BOOL_FALSE;
 		}
 		strcat( fname, INV_INVINDEX_PREFIX );
 		invfd = open( fname, INV_OFLAG(forwhat));
 		if ( invfd < 0 ) {
-			mlog( MLOG_NORMAL | MLOG_INV,
-			     "INV: Open failed on %s\n", 
-			     fname
-			     );
+			mlog( MLOG_NORMAL | MLOG_INV, _(
+			     "INV: Open failed on %s\n"), 
+			     fname );
 			return BOOL_FALSE;
 		}
 
-		if ( search_invt( invfd, NULL, (void **)&moid, 
-				  (search_callback_t) stobj_delete_mobj )
+		if (search_invt(&arr[i].ft_uuid, invfd, NULL, (void **)&moid,
+				(search_callback_t)stobj_delete_mobj)
 		    < 0 )
 			return BOOL_FALSE;
 		/* we have to delete the session, etc */
@@ -851,10 +868,10 @@ static const char *myopts[] = {
 };
 
 
-intgen_t
+int
 inv_getopt(int argc, char **argv, invt_pr_ctx_t *prctx) 
 {
-	intgen_t rval = 0;
+	int rval = 0;
 	void *fs = 0;
 	char *options, *value;
 	extern char *optarg;
@@ -921,7 +938,8 @@ inv_getopt(int argc, char **argv, invt_pr_ctx_t *prctx)
 					bywhat = (inv_predicate_t) INV_BY_UUID;
 					npreds++;
 					
-					uuid_unparse(value, fsid);
+					uuid_parse(value, fsid);
+					fs = fsid;
 					break;
 
 				      case OPT_DEV: /* process dev option */
@@ -941,9 +959,9 @@ inv_getopt(int argc, char **argv, invt_pr_ctx_t *prctx)
 					{
 					uuid_t *u;
 					u = malloc ( sizeof( uuid_t ) );
-					uuid_unparse(value, *u);
+					uuid_parse(value, *u);
 					prctx->mobj.type = INVT_MOID;
-					uuid_copy(prctx->mobj.value, *u);
+					prctx->mobj.value = (void *)u;
 				        }
 					npreds2++;
 					break;
@@ -975,9 +993,9 @@ inv_getopt(int argc, char **argv, invt_pr_ctx_t *prctx)
 					     atoi(value) < PR_MAXDEPTH )
 						prctx->depth = atoi(value);
 					else {
-						mlog( MLOG_NORMAL | MLOG_INV,
+						mlog( MLOG_NORMAL | MLOG_INV, _(
 					       "INV: invalid sub-option %s"
-					       " for -I option\n", value );
+					       " for -I option\n"), value );
 						rval |= I_IERR;
 					}
 					break;
@@ -989,14 +1007,14 @@ inv_getopt(int argc, char **argv, invt_pr_ctx_t *prctx)
 	}
 	
 	if (npreds > 1) {
-		mlog( MLOG_NORMAL | MLOG_INV,
-		     "INV: Only one of mnt=,dev= and fsid=value can be used.\n"
+		mlog( MLOG_NORMAL | MLOG_INV, _(
+		     "INV: Only one of mnt=,dev= and fsid=value can be used.\n")
 		     );
 		rval |= I_IERR;
 	}
 	else if (npreds2 > 1) {
-		mlog( MLOG_NORMAL | MLOG_INV,
-		     "INV: Only one of mobjid= and mobjlabel= can be used.\n"
+		mlog( MLOG_NORMAL | MLOG_INV, _(
+		     "INV: Only one of mobjid= and mobjlabel= can be used.\n")
 		     );
 		rval |= I_IERR;
 	}
@@ -1041,8 +1059,8 @@ inv_getopt(int argc, char **argv, invt_pr_ctx_t *prctx)
 				rval |= I_IDONE;
 			}
 			if ( (rval&I_IERR) ) {
-				mlog( MLOG_NORMAL | MLOG_INV,
-				     "INV: open failed on mount point \"%s\"\n",
+				mlog( MLOG_NORMAL | MLOG_INV, _(
+				    "INV: open failed on mount point \"%s\"\n"),
 				     fs);
 			}
 			return rval;
@@ -1056,8 +1074,9 @@ inv_getopt(int argc, char **argv, invt_pr_ctx_t *prctx)
 			inv_close( tok );
 			rval |= I_IDONE;
 		} else {
-			mlog( MLOG_NORMAL | MLOG_INV, 
-			     "INV: open failed on file system id \"%s\"\n", fs);
+			mlog( MLOG_NORMAL | MLOG_INV, _(
+			     "INV: open failed on file system id \"%s\"\n"),
+			     fs);
 			rval |= I_IERR;
 		}
 	}
@@ -1111,8 +1130,8 @@ inv_DEBUG_print( int argc, char **argv )
 			}
 
 			if (prctx.invcheck) {
-				mlog( MLOG_VERBOSE | MLOG_INV,
-				     "INV: checking fs \"%s\"\n",
+				mlog( MLOG_VERBOSE | MLOG_INV, _(
+				     "INV: checking fs \"%s\"\n"),
 				     &arr[i].ft_mountpt
 				     );
 				invmgr_inv_check(tok->d_invindex_fd);
